# vim: set sw=4 ts=4 et:
#
# spec file for package bombono
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2009-2010 oc2pus
# Copyright (c) 2010      Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without cpp
Name:           bombono
Version:        1.2.4
Release:        10.2
Summary:        DVD authoring program
License:        GPL-2.0
Group:          Productivity/Multimedia/Other
ExclusiveArch:  x86_64
Url:            https://sourceforge.net/projects/bombono
Source:         %{name}-dvd-%{version}.tar.xz
Source99:       bombono-rpmlintrc
Patch0:         bombono.scons.patch
Patch1:         bombono.throw.patch
Patch2:         bombono-dvd-1.2.2_optflags.patch
Patch3:         bombono.operator.patch
Patch4:         bombono.patch
# Import patches from arch
Patch10:        autoptr2uniqueptr.patch
Patch11:        fix_c++11_literal_warnings.patch
Patch12:        fix_deprecated_boost_api.patch
Patch13:        fix_ffmpeg30.patch
Patch14:        fix_ffmpeg_codecid.patch
Patch15:        fix_ptr2bool_cast.patch
BuildRequires:  boost-devel
BuildRequires:  boost-devel
BuildRequires:  boost-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  scons
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dvdread)
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(gdkmm-2.4)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libquicktime)
BuildRequires:  pkgconfig(libxml++-2.6) >= 2.40.1
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mjpegtools)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  fdupes
Requires:       dvd+rw-tools
Requires:       dvdauthor
Requires:       mjpegtools
Requires:       mpeg2demux = %{version}
Requires:       scons
Requires:       twolame
Requires(post): shared-mime-info
Requires(postun): shared-mime-info
Provides:       bombono-dvd = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Bombono DVD is a DVD authoring program for Linux. It is made easy
to use and has nice and clean GUI (Gtk).

The main features of Bombono DVD are:
* Excellent MPEG viewer: Timeline and Monitor
* Real WYSIWYG Menu Editor with live thumbnails
* Comfortable Drag-n-Drop support
* You can author to folder, make ISO-image or burn directly to DVD
* Reauthoring: you can import video from DVD discs.

Bombono DVD is Open Source software and freely distributed under GPL
license.

%package -n     mpeg2demux
Summary:        Demuxer for MPEG2 and VOB files
Group:          Productivity/Multimedia/Other

%description -n mpeg2demux
Demux video from src-file(.mpg, .vob). If src-file has .vob extension then
ac3/dts/lpcm audios are to be pulled too.

%lang_package

%prep
%autosetup -p1 -n %{name}-dvd-%{version}

%build
chmod 644 COPYING
OPTFLAGS="%{optflags} -Wno-reorder"
# Only for libxml++-2.6 >= 2.40.1 with c++11
%if 0%{?suse_version} <= 1320 || (0%{?suse_version} == 1315 && 0%{?is_opensuse})
CPPFLAGS="-DBOOST_NO_CXX11_SCOPED_ENUMS"
%endif

export OPTFLAGS

scons %{?_smp_mflags} \
    BUILD_CFG=release \
    BUILD_BRIEF=false \
    BUILD_QUICK=false \
    CC="gcc" \
    CXX="g++" \
    CFLAGS="%{optflags}" \
    CXXFLAGS="%{optflags}" \
    %{?with_cpp:CPPFLAGS="$CPPFLAGS -std=c++11"} \
    TEST=false \
    TEST_BUILD=false \
    USE_EXT_BOOST=true \
    BOOST_INCLUDE="%{_includedir}" \
    BOOST_LIBPATH="%{_libdir}" \
    DVDREAD_INCLUDE="%{_includedir}" \
    DVDREAD_LIBPATH="%{_libdir}" \
    PREFIX=%{_prefix} \
    DESTDIR=%{buildroot}

%install
OPTFLAGS="%{optflags} -Wno-reorder"
%if 0%{?suse_version} <= 1320 || (0%{?suse_version} == 1315 && 0%{?is_opensuse})
CPPFLAGS="-DBOOST_NO_CXX11_SCOPED_ENUMS"
%endif

export OPTFLAGS

scons \
    BUILD_CFG=release \
    BUILD_BRIEF=false \
    BUILD_QUICK=false \
    CC="gcc" \
    CXX="g++" \
    CFLAGS="%{optflags}" \
    CXXFLAGS="%{optflags}" \
    %{?with_cpp:CPPFLAGS="$CPPFLAGS -std=c++11"} \
    TEST=false \
    TEST_BUILD=false \
    USE_EXT_BOOST=true \
    BOOST_INCLUDE="%{_includedir}" \
    BOOST_LIBPATH="%{_libdir}" \
    DVDREAD_INCLUDE="%{_includedir}" \
    DVDREAD_LIBPATH="%{_libdir}" \
    PREFIX=%{_prefix} \
    DESTDIR=%{buildroot} \
    install

%suse_update_desktop_file -i %{name}-dvd AudioVideo AudioVideoEditing

chmod 755 %{buildroot}%{_datadir}/%{name}/resources/scons_authoring/menu_SConscript

find "%{buildroot}%{_datadir}/%{name}/resources/icons/" -type f -executable -exec chmod 0644 {} \;

%find_lang %{name}-dvd

%fdupes -s %{buildroot}%{_datadir}

%post
%mime_database_post
%icon_theme_cache_post
%desktop_database_post

%postun
%mime_database_postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%license COPYING
%{_bindir}/%{name}-dvd
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/pixmaps/*.png
%{_datadir}/icons/*/*/apps/%{name}-dvd.*
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man1/%{name}-dvd.1%{ext_man}

%files -n mpeg2demux
%license COPYING
%{_bindir}/mpeg2demux
%{_mandir}/man1/mpeg2demux.1%{ext_man}

%files lang -f %{name}-dvd.lang

%changelog
* Mon Oct 24 2016 olaf@aepfle.de
- Update to 1.2.4
  * add autoptr2uniqueptr.patch
  * add fix_c++11_literal_warnings.patch
  * add fix_deprecated_boost_api.patch
  * add fix_ffmpeg30.patch
  * add fix_ffmpeg_codecid.patch
- build with ffmpeg2
* Mon Apr  4 2016 avvissu@yandex.by
- Remove source code (libxml++-2.34.2.tar.bz2):
  * use libxml++-2.6 from PMBS
- Update patches:
  * bombono-optflags.patch -> bombono-dvd-1.2.2_optflags.patch
- Fix build with libxml++-2.6 >= 2.40.1:
  * add fix_ptr2bool_cast.patch
  * add stream_bool_cast.patch
  * add fix_crefoftemp_bug.patch
- Use the flag -std=c++11
- Use pkgconfig(style)
- Spec file cleanup
* Wed Oct 15 2014 avvissu@yandex.ru
- Update to 1.2.2
- Spec-file: leaving everything as it is
* Tue May 29 2012 Manfred.Tremmel@iiv.de
- ffmpeg doen't include url.h anymorecompile against ffmpeg_oldabi
* Tue May 22 2012 seife+obs@b1-systems.com
- remove obsoleted glib includes to fix build on > 12.1
* Sat Feb 11 2012 pascal.bleser@opensuse.org
- update to 1.2.1
* Sun Jan  1 2012 pascal.bleser@opensuse.org
- add ffmpeg_arch.diff to fix build with newest ffmpeg
- BR against libmjpegutils-devel instead of mjpegtools-devel as someone decided
  unilateraly to rename it there without obsoletes+requires and without
  checking whether it breaks Packman, thank you very much
* Sat Nov 26 2011 pascal.bleser@opensuse.org
- update to 1.2.0
* Tue Nov 22 2011 pascal.bleser@opensuse.org
- remove rpaths
* Tue Jun  7 2011 pascal.bleser@opensuse.org
- add scons to Requires, fixes BNC#684814:
  https://bugzilla.novell.com/show_bug.cgi?id=684814
* Sun May 29 2011 pascal.bleser@opensuse.org
- add bombono-fix_deprecated_ffmpeg_usage.patch to remove deprecated ffmpeg API
  usage
* Sun May 29 2011 pascal.bleser@opensuse.org
- add bombono-always-wrap-xml.patch (thanks to Bastian Friedrich), currently
  only on 11.4, which requires an in-tree build of the latest libxml++ because
  it uses Node::create_wrapper() which is only available there and not in the
  libxml++ that ships with openSUSE 11.4;
  fixes http://sourceforge.net/apps/trac/bombono/ticket/53
* Sun May 22 2011 pascal.bleser@opensuse.org
- update to 1.0.2:
  * libxml++ 2.33.1 changes: projects can be opened
  * update for spumux, dvdauthor 0.7.0
  * one line setting ~/.config/bombono-dvd/av_seek_shift: set to "-N" (e.g. -4
    seconds) to avoid missing keyframes/visual artefacts of videos
- mpeg2demux split out as its own package
- added man pages from Debian
* Thu Mar 17 2011 detlef@links2linux.de
- update to 1.0.1
* Fri Jan  7 2011 pascal.bleser@opensuse.org
- update to 1.0.0-1 (upstream git revision
  1e9303ab8c5705491ad6ab693c9f8c9ada341fcb) to fix using bombono-dvd with newer
  ffmpeg
* Fri Dec 31 2010 pascal.bleser@opensuse.org
- update to 1.0.0
* Sun Apr 18 2010 toni@links2linux.de
- update to 0.6.0
* Wed Apr  7 2010 toni@links2linux.de
- update to 0.5.10
* Wed Nov 11 2009 toni@links2linux.de
- added a patch to support twolame instead of toolame
* Sat Oct 24 2009 toni@links2linux.de
- Initial package 0.5.2
